@@ -238,7 +238,7 @@ void TrackView::OnSortingSelectionChanged(int currSelection)
             m_pPlaylist->sortByAlbums(true);
         else if(currSelection==ALBUM_DESC)
             m_pPlaylist->sortByAlbums(false);
-        else if(currSelection==MOST_POPULAR)
+        else if(currSelection==MOST_POPULAR_DESC)
             m_pPlaylist->sortByPopularity();
         addTracks(m_pPlaylist);
     }
@@ -259,7 +259,7 @@ void TrackView::OnSortingSelectionChanged(int currSelection)
             qSort(m_TrackList.begin(),m_TrackList.end(),tracksByAlbumNameAsc);
         else if(currSelection==ALBUM_DESC)
             qSort(m_TrackList.begin(),m_TrackList.end(),tracksByAlbumNameDesc);
-        else if(currSelection==MOST_POPULAR)
+        else if(currSelection==MOST_POPULAR_DESC)
             qSort(m_TrackList.begin(),m_TrackList.end(),tracksByPopularityDesc);
         addTracks(m_TrackList);
     }
@@ -278,7 +278,7 @@ void TrackView::setPlaylist(Spotify::Playlist* pPlaylist)
 
             setWindowTitle(pPlaylist->getName());
 
-            m_pSortByAct->setCurrentSelection(0); //set sorting to Original order
+            m_pSortByAct->setCurrentSelection(MOST_POPULAR_DESC); //set sorting to Most Popular (descending) order
 
             m_pPlaylist->restoreOrignalCollection();
 
@@ -291,7 +291,6 @@ void TrackView::setSearchResults(Spotify::Search* pSearch)
     //Set the search results to be displayed
 
     m_pPlaylist = NULL;
-
     if(pSearch)
     {
         setWindowTitle(tr("Search results: ") + pSearch->getSearchQuery());
@@ -299,9 +298,9 @@ void TrackView::setSearchResults(Spotify::Search* pSearch)
         m_pSortByAct->populateListModel(m_SearchSortByList); //populate sorting alternatives
 
         m_TrackList = pSearch->getTracks(false); //only return available tracks
-        m_pSortByAct->setCurrentSelection(0); //set sorting to Original order
-	//sort track instance first by artist, then by album, and finally by track
-	qSort(m_TrackList.begin(),m_TrackList.end(),trackLessThanCaseInsensitive); 
+        m_pSortByAct->setCurrentSelection(MOST_POPULAR_DESC); //set sorting to Most Popular (desc)
+        //sort track instances by most popular (desc)
+        qSort(m_TrackList.begin(),m_TrackList.end(),tracksByPopularityDesc);
         addTracks(m_TrackList);
     }
 }
