@@ -1,14 +1,15 @@
 #include "imagecontainer.h"
-#include <QDebug>
 namespace Spotify
 {
-    ImageContainer::ImageContainer()
+    ImageContainer::ImageContainer(QObject* parent)
+        : QObject(parent)
     {
     }
 
     void ImageContainer::setImage( QImage image )
     {
         m_image = image;
+        emit loaded();
     }
 
     QImage ImageContainer::getImage() const
