@@ -63,13 +63,15 @@ static void playlistMetadataUpdatedCallback( sp_playlist* pl, void* userdata )
 
 namespace Spotify
 {
-    Playlist::Playlist(sp_session* session, sp_playlist* playlist, QObject* parent ):
+    Playlist::Playlist(sp_session* session, int type, sp_playlist* playlist, QObject* parent ):
             TrackCollection( parent ),
             m_session( session ),
             m_playlist( playlist ),
             m_owner( 0 ),
             m_position( 0 ),
-            m_isOffline( false )
+            m_isOffline( false ),
+            m_type( type ),
+            m_hasRef( false )
     {
         m_callbacks = new sp_playlist_callbacks(); //allocate playlist callbacks instance
         m_callbacks->tracks_added = tracksAddedCallback;
@@ -87,6 +89,8 @@ namespace Spotify
         sp_playlist_add_callbacks(m_playlist,m_callbacks,NULL); //register playlist callbacks
 
         m_isLoaded = false;
+        if(type==PLAYLIST_TYPE_STARRED)
+            m_name = tr("Starred tracks");
         load(); //attempt to load metadata for playlist
     }
 
@@ -151,6 +155,11 @@ namespace Spotify
         }
     }
 
+    int Playlist::getType()
+    {
+        return m_type;
+    }
+
     ePlaylistOfflineStatus Playlist::getOfflineStatus()
     {
         return m_offlineStatus;
@@ -165,6 +174,9 @@ namespace Spotify
             sp_playlist_remove_callbacks(m_playlist,m_callbacks,NULL);
             delete m_callbacks;
         }
+
+        if(m_hasRef) //corresponding sp_playlist object needs to be released explicitly
+           sp_playlist_release(m_playlist);
     }
 
     void Playlist::tracksAdded(sp_track** tracks, qint32 num_tracks, qint32 position)
